@@ -17,7 +17,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 #-------------------------------------------------------------------------
@@ -32,8 +32,6 @@ from gi.repository import Gtk
 # Standard Python modules
 #
 #-------------------------------------------------------------------------
-from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
 from collections import defaultdict
 
 #-------------------------------------------------------------------------
@@ -41,6 +39,8 @@ from collections import defaultdict
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.gettext
 from gramps.gen.const import PLUGINS_GLADE
 from gramps.gen.plug.report._constants import standalone_categories
 from . import tool
@@ -88,6 +88,7 @@ class PluginDialog(ManagedWindow):
         self.uistate = uistate
         
         self.dialog = Gtk.Builder()
+        self.dialog.set_translation_domain(glocale.get_localedomain())
         self.dialog.add_from_file(PLUGINS_GLADE)
         self.dialog.connect_signals({
             "on_report_apply_clicked" : self.on_apply_clicked,
