@@ -54,7 +54,6 @@ from gramps.gui.plug.export import WriterOptionBox
 from gramps.gen.updatecallback import UpdateCallback
 from gramps.gen.utils.file import media_path_full
 from gramps.gen.utils.place import conv_lat_lon
-from gramps.gen.constfunc import cuni
 from gramps.gen.utils.location import get_main_location
 from gramps.gen.display.place import displayer as place_displayer
 
@@ -273,17 +272,17 @@ class GedcomWriter(UpdateCallback):
             token_level = level
             for text in textlist:
                 # make it unicode so that breakup below does the right thin.
-                text = cuni(text)
+                text = str(text)
                 if limit:
-                    prefix = cuni("\n%d CONC " % (level + 1))
+                    prefix = "\n%d CONC " % (level + 1)
                     txt = prefix.join(breakup(text, limit))
                 else:
                     txt = text
-                self.gedcom_file.write(cuni("%d %s %s\n" % (token_level, token, txt)))
+                self.gedcom_file.write("%d %s %s\n" % (token_level, token, txt))
                 token_level = level + 1
                 token = "CONT"
         else:
-            self.gedcom_file.write(cuni("%d %s\n" % (level, token)))
+            self.gedcom_file.write("%d %s\n" % (level, token))
     
     def _header(self, filename):
         """
@@ -334,7 +333,7 @@ class GedcomWriter(UpdateCallback):
         self._writeln(1, "FILE", filename, limit=255)
         self._writeln(1, "COPR", 'Copyright (c) %d %s.' % (year, rname))
         self._writeln(1, "GEDC")
-        self._writeln(2, "VERS", "5.5")
+        self._writeln(2, "VERS", "5.5.1")
         self._writeln(2, "FORM", 'LINEAGE-LINKED')
         self._writeln(1, "CHAR", "UTF-8")
         
@@ -532,16 +531,27 @@ class GedcomWriter(UpdateCallback):
         extract the real event to discover the event type.
         
         """
+        global adop_written
+        # adop_written is only shared between this function and
+        # _process_person_event. This is rather ugly code, but it is difficult
+        # to support an Adoption event without an Adopted relationship from the
+        # parent(s), an Adopted relationship from the parent(s) without an
+        # event, and both an event and a relationship. All these need to be
+        # supported without duplicating the output of the ADOP GEDCOM tag. See
+        # bug report 2370.
+        adop_written = False
         for event_ref in person.get_event_ref_list():
             event = self.dbase.get_event_from_handle(event_ref.ref)
             if not event: continue
-            self._process_person_event(event, event_ref)
-        self._adoption_records(person)
+            self._process_person_event(person, event, event_ref)
+        if not adop_written:
+            self._adoption_records(person, adop_written)
 
-    def _process_person_event(self, event, event_ref):
+    def _process_person_event(self, person, event, event_ref):
         """
         Process a person event, which is not a BIRTH or DEATH event.
         """
+        global adop_written
         etype = int(event.get_type())
         # if the event is a birth or death, skip it.
         if etype in (EventType.BIRTH, EventType.DEATH):
@@ -578,8 +588,11 @@ class GedcomWriter(UpdateCallback):
             if descr:
                 self._writeln(2, 'NOTE', "Description: " + descr)
         self._dump_event_stats(event, event_ref)
+        if etype == EventType.ADOPT and not adop_written:
+            adop_written = True
+            self._adoption_records(person, adop_written)
 
-    def _adoption_records(self, person):
+    def _adoption_records(self, person, adop_written):
         """
         Write Adoption events for each child that has been adopted.
 
@@ -603,7 +616,8 @@ class GedcomWriter(UpdateCallback):
                     adoptions.append((family, child_ref.frel, child_ref.mrel))
 
         for (fam, frel, mrel) in adoptions:
-            self._writeln(1, 'ADOP', 'Y')
+            if not adop_written:
+                self._writeln(1, 'ADOP', 'Y')
             self._writeln(2, 'FAMC', '@%s@' % fam.get_gramps_id())
             if mrel == frel:
                 self._writeln(3, 'ADOP', 'BOTH')
@@ -1080,7 +1094,7 @@ class GedcomWriter(UpdateCallback):
 
         if event.get_place_handle():
             place = self.dbase.get_place_from_handle(event.get_place_handle())
-            self._place(place, 2)
+            self._place(place, dateobj, 2)
 
         for attr in event.get_attribute_list():
             attr_type = attr.get_type()
@@ -1151,8 +1165,8 @@ class GedcomWriter(UpdateCallback):
         if lds_ord.get_temple():
             self._writeln(index+1, 'TEMP', lds_ord.get_temple())
         if lds_ord.get_place_handle():
-            self._place(
-                self.dbase.get_place_from_handle(lds_ord.get_place_handle()), 2)
+            place = self.dbase.get_place_from_handle(lds_ord.get_place_handle())
+            self._place(place, lds_ord.get_date_object(), 2)
         if lds_ord.get_status() != LdsOrd.STATUS_NONE:
             self._writeln(2, 'STAT', LDS_STATUS[lds_ord.get_status()])
         
@@ -1170,16 +1184,22 @@ class GedcomWriter(UpdateCallback):
             cal = date.get_calendar()
             mod = date.get_modifier()
             quality = date.get_quality()
+            if quality in libgedcom.DATE_QUALITY:
+                qual_text = libgedcom.DATE_QUALITY[quality] + " "
+            else:
+                qual_text = ""
             if mod == Date.MOD_SPAN:
-                val = "FROM %s TO %s" % (
-                    libgedcom.make_gedcom_date(start, cal, mod, quality), 
+                val = "%sFROM %s TO %s" % (
+                    qual_text,
+                    libgedcom.make_gedcom_date(start, cal, mod, None), 
                     libgedcom.make_gedcom_date(date.get_stop_date(), 
-                                               cal, mod, quality))
+                                               cal, mod, None))
             elif mod == Date.MOD_RANGE:
-                val = "BET %s AND %s" % (
-                    libgedcom.make_gedcom_date(start, cal, mod, quality), 
+                val = "%sBET %s AND %s" % (
+                    qual_text,
+                    libgedcom.make_gedcom_date(start, cal, mod, None), 
                     libgedcom.make_gedcom_date(date.get_stop_date(), 
-                                               cal, mod, quality))
+                                               cal, mod, None))
             else:
                 val = libgedcom.make_gedcom_date(start, cal, mod, quality)
             self._writeln(level, 'DATE', val)
@@ -1350,7 +1370,7 @@ class GedcomWriter(UpdateCallback):
 
             self._note_references(photo_obj.get_note_list(), level+1)
 
-    def _place(self, place, level):
+    def _place(self, place, dateobj, level):
         """
         PLACE_STRUCTURE:=
             n PLAC <PLACE_NAME> {1:1}
@@ -1365,7 +1385,7 @@ class GedcomWriter(UpdateCallback):
             +1 <<NOTE_STRUCTURE>> {0:M} 
         """
         if place is None: return
-        place_name = place_displayer.display(self.dbase, place)
+        place_name = place_displayer.display(self.dbase, place, dateobj)
         self._writeln(level, "PLAC", place_name.replace('\r', ' '), limit=120)
         longitude = place.get_longitude()
         latitude = place.get_latitude()
